package dbrown;

import java.awt.Dimension;
import java.awt.Point;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;

/**
 * Provides a frame and a label to display information about the execution of a
 * chef process.
 *
 * @author David Brown
 * @version 2012-11-15
 */
@SuppressWarnings("serial")
public class ChefView extends JFrame {
    /**
     * Displays the current status of the chef.
     */
    private class ChefListener implements PropertyChangeListener {

	@Override
	public void propertyChange(final PropertyChangeEvent evt) {
	    final int status = (Integer) evt.getNewValue();

	    switch (status) {
	    case Chef.FREE:
		ChefView.this.label.setText("Free");
		break;
	    case Chef.COOKING:
		ChefView.this.label.setText("Cooking Order "
			+ ChefView.this.chef.getOrder().getNumber());
		break;
	    case Chef.DONE:
		ChefView.this.label.setText("Done");
		break;
	    }
	}
    }

    // -------------------------------------------------------------------------------
    // Constants
    private Chef chef = null;
    private final JPanel panel = new JPanel();
    private final JLabel label = new JLabel("Free");

    /**
     * @param chef
     * @param location
     */
    public ChefView(final Chef chef, final Point location,
	    final Dimension size) {
	this.chef = chef;
	this.setSize(size);
	this.setLocation(location);
	this.layoutView();
	this.registerListeners();
    }

    /**
     * Lays out out the main panel and frame.
     */
    private void layoutView() {
	this.setTitle("Chef");
	this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	this.panel.add(this.label);
	this.setContentPane(this.panel);
    }

    /**
     * Registers the views listeners.
     */
    private void registerListeners() {
	this.chef.addPropertyChangeListener(new ChefListener());
    }

}
