package dbrown;

/**
 * A simple class representing restaurant orders that tracks how many objects
 * have been instantiated from it and whether the maximum number of objects
 * allowed have been created.
 *
 * @author David B. Brown from Bruce Eckel
 * @version 2015-12-02
 */
class Order {
    /**
     * Tracks the total number of orders placed.
     */
    private static int count = 0;

    /**
     * The maximum number of orders that can be placed.
     */
    private final static int ORDERS = 10;

    /**
     * The number of a particular order. This number can be accessed using the
     * getter <code>getNumber</code>, but cannot be set.
     */
    private final int number = Order.count++;

    /**
     * Returns the order number.
     *
     * @return Returns the order number.
     */
    public int getNumber() {
	return this.number;
    }

    /**
     * Determines whether an order is the last order.
     *
     * @return whether this is the last order or not.
     */
    public boolean isLastOrder() {
	return this.number == Order.ORDERS;
    }

    /*
     * (non-Javadoc)
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
	return "Order: " + this.number;
    }
}