package dbrown;

import java.awt.Font;
import java.awt.Point;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;

/**
 * Provides a frame and a text area to display information about the execution
 * of the restaurant process.
 *
 * @author David Brown
 * @version 2015-12-02
 */
@SuppressWarnings("serial")
public class RestaurantView extends JFrame {

    /**
     * Displays the current state of the model.
     */
    private class RestaurantListener implements PropertyChangeListener {

	@Override
	public void propertyChange(final PropertyChangeEvent evt) {
	    RestaurantView.this.textArea.append((String) evt.getNewValue());
	    RestaurantView.this.textArea.append("\n");
	}
    }

    // -------------------------------------------------------------------------------
    private Restaurant restaurant = null;
    private final JTextArea textArea = new JTextArea();
    // Places the text area inside a scroll bar pane.
    private final JScrollPane textScroll = new JScrollPane(this.textArea);

    /**
     * Construct the restaurant view.
     *
     * @param restaurant
     * @param location
     */
    public RestaurantView(final Restaurant restaurant, final Point location) {
	this.restaurant = restaurant;
	this.setLocation(location);
	this.layoutView();
	this.registerListeners();
    }

    /**
     * Lays out out the main panel and frame.
     */
    private void layoutView() {
	this.setTitle("Restaurant");
	this.textArea.setEnabled(false);
	this.textArea.setFont(new Font("Verdana", Font.BOLD, 18));
	this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	this.setContentPane(this.textScroll);
	this.pack();
	this.setSize(500, 600);
    }

    /**
     * Registers the views listeners.
     */
    private void registerListeners() {
	this.restaurant.addPropertyChangeListener(new RestaurantListener());
    }

}
