package dbrown;

import java.awt.Dimension;
import java.awt.Point;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;

/**
 * Provides a frame and a label to display information about the execution of a
 * waiter process.
 *
 * @author David Brown
 * @version 2015-12-02
 */
@SuppressWarnings("serial")
public class WaiterView extends JFrame {
    /**
     * Displays the current status of the waiter.
     */
    private class WaiterListener implements PropertyChangeListener {

	@Override
	public void propertyChange(final PropertyChangeEvent evt) {
	    final int status = (Integer) evt.getNewValue();

	    switch (status) {
	    case Waiter.FREE:
		WaiterView.this.label.setText("Free");
		break;
	    case Waiter.SERVING:
		WaiterView.this.label.setText("Serving Order "
			+ WaiterView.this.waiter.getOrder().getNumber());
		break;
	    case Waiter.DONE:
		WaiterView.this.label.setText("Done");
		break;
	    }
	}
    }

    // -------------------------------------------------------------------------------
    private final Waiter waiter;
    private final JLabel label = new JLabel("Free");
    private final JPanel panel = new JPanel();

    /**
     * @param waiter
     * @param location
     */
    public WaiterView(final Waiter waiter, final Point location,
	    final Dimension size) {
	this.waiter = waiter;
	this.setLocation(location);
	this.setSize(size);
	this.layoutView();
	this.registerListeners();
    }

    /**
     * Lays out out the main panel and frame.
     */
    private void layoutView() {
	this.setTitle("Waiter " + this.waiter.getNumber());
	this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	this.panel.add(this.label);
	this.setContentPane(this.panel);
    }

    /**
     * Registers the views listeners.
     */
    private void registerListeners() {
	this.waiter.addPropertyChangeListener(new WaiterListener());
    }
}
